==> wine-1.1.0.tar.bz2: wine-1.1.0/programs/winhlp32/winhelp_res.h <==
#define MNID_FILE_OPEN          0x101
#define MNID_FILE_PRINT         0x104
#define MNID_FILE_SETUP         0x106
#define MNID_FILE_EXIT          0x108

#define MNID_EDIT_COPYDLG       0x111
#define MNID_EDIT_ANNOTATE      0x112

#define MNID_BKMK_DEFINE        0x121

#define MNID_OPTS_HELP_DEFAULT  0x131
#define MNID_OPTS_HELP_VISIBLE  0x132
#define MNID_OPTS_HELP_NONVISIBLE 0x133
#define MNID_OPTS_HISTORY       0x134
#define MNID_OPTS_FONTS_SMALL   0x135
#define MNID_OPTS_FONTS_NORMAL  0x136
#define MNID_OPTS_FONTS_LARGE   0x137
#define MNID_OPTS_SYSTEM_COLORS 0x138

#define MNID_HELP_HELPON        0x141
#define MNID_HELP_HELPTOP       0x142
#define MNID_HELP_ABOUT         0x143
#define MNID_HELP_WINE          0x144

#define MNID_CTXT_ANNOTATE      0x200
#define MNID_CTXT_COPY          0x201
#define MNID_CTXT_PRINT         0x202
#define MNID_CTXT_FONTS_SMALL   0x210
#define MNID_CTXT_FONTS_NORMAL  0x211
#define MNID_CTXT_FONTS_LARGE   0x212
#define MNID_CTXT_HELP_DEFAULT  0x220
#define MNID_CTXT_HELP_VISIBLE  0x221
#define MNID_CTXT_HELP_NONVISIBLE 0x222
#define MNID_CTXT_SYSTEM_COLORS 0x230

#define MAIN_MENU		0xF000
#define CONTEXT_MENU            0xF001

#define STID_WINE_HELP		0x120
#define STID_WHERROR		0x121
#define STID_WARNING  		0x122
#define STID_INFO  		0x123
#define STID_NOT_IMPLEMENTED 	0x124
#define STID_HLPFILE_ERROR_s 	0x125
#define STID_CONTENTS 		0x126
#define STID_SEARCH	 	0x127
#define STID_BACK 		0x128
#define STID_TOPICS 		0x12A
#define STID_ALL_FILES 		0x12B
#define STID_HELP_FILES_HLP	0x12C
#define STID_DIALOG_TEST	0x12D
#define STID_FILE_NOT_FOUND_s	0x12E
#define STID_NO_RICHEDIT        0x12F

#define IDD_INDEX               0x150
#define IDC_INDEXLIST           0x151

#define IDI_WINHELP             0xF00

==> wine-1.3.14.tar.bz2: wine-1.3.14/programs/winhlp32/winhelp_res.h <==
#include <windef.h>
#include <winuser.h>

#define MNID_FILE_OPEN          0x101
#define MNID_FILE_PRINT         0x104
#define MNID_FILE_SETUP         0x106
#define MNID_FILE_EXIT          0x108

#define MNID_EDIT_COPYDLG       0x111
#define MNID_EDIT_ANNOTATE      0x112

#define MNID_BKMK_DEFINE        0x121

#define MNID_OPTS_HELP_DEFAULT  0x131
#define MNID_OPTS_HELP_VISIBLE  0x132
#define MNID_OPTS_HELP_NONVISIBLE 0x133
#define MNID_OPTS_HISTORY       0x134
#define MNID_OPTS_FONTS_SMALL   0x135
#define MNID_OPTS_FONTS_NORMAL  0x136
#define MNID_OPTS_FONTS_LARGE   0x137
#define MNID_OPTS_SYSTEM_COLORS 0x138

#define MNID_HELP_HELPON        0x141
#define MNID_HELP_HELPTOP       0x142
#define MNID_HELP_ABOUT         0x143

#define MNID_CTXT_ANNOTATE      0x200
#define MNID_CTXT_COPY          0x201
#define MNID_CTXT_PRINT         0x202
#define MNID_CTXT_FONTS_SMALL   0x210
#define MNID_CTXT_FONTS_NORMAL  0x211
#define MNID_CTXT_FONTS_LARGE   0x212
#define MNID_CTXT_HELP_DEFAULT  0x220
#define MNID_CTXT_HELP_VISIBLE  0x221
#define MNID_CTXT_HELP_NONVISIBLE 0x222
#define MNID_CTXT_SYSTEM_COLORS 0x230

#define MAIN_MENU		0xF000
#define CONTEXT_MENU            0xF001

#define STID_WINE_HELP		0x120
#define STID_WHERROR		0x121
#define STID_WARNING  		0x122
#define STID_INFO  		0x123
#define STID_NOT_IMPLEMENTED 	0x124
#define STID_HLPFILE_ERROR_s 	0x125
#define STID_CONTENTS 		0x126
#define STID_INDEX	 	0x127
#define STID_BACK 		0x128
#define STID_ALL_FILES 		0x12B
#define STID_HELP_FILES_HLP	0x12C
#define STID_DIALOG_TEST	0x12D
#define STID_FILE_NOT_FOUND_s	0x12E
#define STID_NO_RICHEDIT        0x12F
#define STID_PSH_INDEX          0x130

#define IDD_INDEX               0x150
#define IDC_INDEXLIST           0x151
#define IDD_SEARCH              0x152

#define IDI_WINHELP             0xF00
